.. include:: tutorials/README.rst

User tutorials
--------------

.. toctree::
    :maxdepth: 1

    tutorials/tut_intro.ipynb
    tutorials/tut_buildsim.ipynb
    tutorials/tut_demographics.ipynb
    tutorials/tut_diseases.ipynb
    tutorials/tut_transmission.ipynb
    tutorials/tut_interventions.ipynb

Developer tutorials
-------------------

.. toctree::
    :maxdepth: 1

    tutorials/dev_tut_diseases.ipynb
    tutorials/dev_tut_pars.ipynb
    tutorials/dev_tut_analyzers.ipynb
    tutorials/dev_tut_nonstandard.ipynb
    
